Library Header Files
====
* This folder contains all the header needed to use the library
* To use it, add the "include" folder to the search path of the compiler
* User only needs to know [rabit.h](rabit.h) and [rabit_serializable.h](rabit_serializable.h) in order to use the library
* Folder [rabit](rabit) contains headers for internal engine and template's implementation
* Not all .h files in the project are in the "include" folder, .h files that are internally used by the library remain at [src](../src)
